<?php

namespace Research\Chapter\Policies;

use Litepie\User\Contracts\UserPolicy;
use Research\Chapter\Models\Chapter;

class ChapterPolicy
{

    /**
     * Determine if the given user can view the chapter.
     *
     * @param UserPolicy $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function view(UserPolicy $user, Chapter $chapter)
    {
        if ($user->canDo('chapter.chapter.view') && $user->isAdmin()) {
            return true;
        }

        return $chapter->user_id == user_id() && $chapter->user_type == user_type();
    }

    /**
     * Determine if the given user can create a chapter.
     *
     * @param UserPolicy $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('chapter.chapter.create');
    }

    /**
     * Determine if the given user can update the given chapter.
     *
     * @param UserPolicy $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function update(UserPolicy $user, Chapter $chapter)
    {
        if ($user->canDo('chapter.chapter.edit') && $user->isAdmin()) {
            return true;
        }

        return $chapter->user_id == user_id() && $chapter->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given chapter.
     *
     * @param UserPolicy $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Chapter $chapter)
    {
        return $chapter->user_id == user_id() && $chapter->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given chapter.
     *
     * @param UserPolicy $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Chapter $chapter)
    {
        if ($user->canDo('chapter.chapter.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given chapter.
     *
     * @param UserPolicy $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Chapter $chapter)
    {
        if ($user->canDo('chapter.chapter.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
